package sgc.portal.cs.cs0403.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0403.dto.CS04030001USearch;
import sgc.portal.cs.cs0403.model.CS04030001U;

import java.util.List;
import java.util.Map;

@Mapper
public interface CS04030001UMapper {
	
	//주간 현장별 주요현안
	List<EasyHashMap<String, Object>> selectTcsWeekWorkMainisuList(CS04030001USearch search);
	List<EasyHashMap<String, Object>> selectTcsWeekWorkMainisuDtlList(CS04030001USearch search);
	
	int selectTcsWeekWorkMainisuCount(CS04030001U cS04030001U);
	String selectworkBasedateTo(CS04030001U cS04030001U);
	List<EasyHashMap<String, Object>> selectTcsWeekWorkMainisuCommList1(CS04030001USearch search);
	List<EasyHashMap<String, Object>> selectTcsWeekWorkMainisuCommList2(CS04030001USearch search);
	
	void insertTcsWeekWorkMainisu(CS04030001U  cS04030001U);
	void deleteTcsWeekWorkMainisu(CS04030001U  cS04030001U);
	void updateTcsWeekWorkMainisu(CS04030001U  cS04030001U);
	
	void insertTcsWeekWorkMainisu2(CS04030001U  cS04030001U);
}
